#!/usr/bin/env python
# -*- coding: utf-8 -*-

# PyMOSP - PyMOSP is a Python library to access MOSP.
# Copyright (C) 2019-2022 Cédric Bonhomme - https://www.cedricbonhomme.org
# Copyright (C) 2019-2022 SECURITYMADEIN.LU
#
# For more information : https://github.com/CASES-LU/PyMOSP
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

import os
import argparse

try:
    import pymosp
except Exception:
    print("Install PyMOSP: pipx install pymosp")


def main():
    try:
        py_mosp = pymosp.PyMOSP(os.getenv("MOSP_URL_API", ""), os.getenv("TOKEN", ""))
    except Exception as e:
        print(e)

    parser = argparse.ArgumentParser(prog="PyMOSP")
    subparsers = parser.add_subparsers(help="sub-command help", dest="command")

    # Subparser: Object
    parser_object = subparsers.add_parser("object", help="object help")
    parser_object.add_argument(
        "--list", default=True, action=argparse.BooleanOptionalAction
    )

    arguments = parser.parse_args()

    if arguments.command == "object":
        if arguments.list:
            r = py_mosp.objects()
            print(r)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-


class PyMOSPError(Exception):
    def __init__(self, message):
        super(PyMOSPError, self).__init__(message)
        self.message = message


class NoURL(PyMOSPError):
    pass



# -*- coding: utf-8 -*-

"""
API.
"""
import sys
from typing import List, Dict, Union, Mapping, Iterable

import requests
from urllib.parse import urljoin

from .exceptions import NoURL
from .mospobject import MOSPObject


class PyMOSP:
    """Python API to access MOSP.

    :param url: URL of the MOSP instance you want to connect to
    :param key: API key of the user you want to use
    """

    def __init__(self, url: str, key: str):
        if not url:
            raise NoURL("Please provide the URL of your MOSP instance.")
        self.root_url = url
        self.key: str = key

    # ## BEGIN Objects ##

    def objects(
        self, params: Mapping = {}, pythonify: bool = False
    ) -> Union[Dict, List[MOSPObject]]:
        """Get all the events from the MOSP instance."""
        r = self._prepare_request("GET", "object", params=params)
        return r.json()

    def add_objects(
        self, objects: List[MOSPObject], pythonify: bool = False
    ) -> Union[Dict, List[MOSPObject]]:
        """Add a new object on a MOSP instance.

        :param objects: event to add
        :param pythonify: Returns a PyMOSP Object instead of the plain json output
        """

        r = self._prepare_request("POST", "object/", data=objects)
        return r.json()

    def delete_object(self, id: int) -> int:
        """Delete an object from a MOSP instance.
        Returns the HTTP status code from the MOSP instance.

        :param id: The id of the object to delete.
        """
        r = self._prepare_request("DELETE", "object/{}".format(id))
        return r.status_code

    # ## BEGIN Schemas ##

    def schemas(
        self, params: Mapping = {}, pythonify: bool = False
    ) -> Union[Dict, List[MOSPObject]]:
        """Get all the events from the MOSP instance."""
        r = self._prepare_request("GET", "schema", params=params)
        return r.json()

    # Helpers

    def _prepare_request(
        self,
        request_type: str,
        url: str,
        data: Union[str, Iterable, Mapping] = {},
        params: Mapping = {},
    ) -> requests.Response:
        url = urljoin(self.root_url, url)

        user_agent = f'PyMOSP - Python {".".join(map(str, sys.version_info[:2]))}'
        headers = {
            "X-API-KEY": self.key,
            "Accept": "application/json",
            "Content-Type": "application/json",
            "User-Agent": user_agent,
        }

        r = requests.request(
            request_type, url, headers=headers, json=data, params=params
        )
        # objects_r = self._check_json_response(r)

        # print(r.json())

        return r

    # def _check_json_response(self, response: requests.Response) -> Dict:  # type: ignore
    #     r = self._check_response(response, expect_json=True)
    #     if isinstance(r, (dict, list)):
    #         return r



# -*- coding: utf-8 -*-

from datetime import datetime


class MOSPObject:
    def __init__(self):
        self.name: str
        self.description: str
        self.last_updated: datetime
        self.json_object: dict



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pymosp']

package_data = \
{'': ['*']}

install_requires = \
['mypy>=0.931,<0.932',
 'requests>=2.25.1,<3.0.0',
 'types-requests>=2.27.5,<3.0.0']

entry_points = \
{'console_scripts': ['pymosp = bin.pymosp:main']}

setup_kwargs = {
    'name': 'pymosp',
    'version': '0.5.0',
    'description': 'Python Library to access MOSP.',
    'long_description': '# PyMOSP\n\n[![Latest release](https://img.shields.io/github/release/CASES-LU/PyMOSP.svg?style=flat-square)](https://github.com/CASES-LU/PyMOSP/releases/latest)\n[![License](https://img.shields.io/github/license/CASES-LU/PyMOSP.svg?style=flat-square)](https://www.gnu.org/licenses/agpl-3.0.html)\n[![Workflow](https://github.com/CASES-LU/PyMOSP/workflows/Python%20application/badge.svg?style=flat-square)](https://github.com/CASES-LU/PyMOSP/actions?query=workflow%3A%22Python+application%22)\n[![PyPi version](https://img.shields.io/pypi/v/pymosp.svg?style=flat-square)](https://pypi.org/project/pymosp)\n\n\nPyMOSP is a Python library to access [MOSP](https://github.com/CASES-LU/MOSP).\n\n\n## Installation\n\n### Use it as a command line tool\n\n```bash\n$ pipx install pymosp\ninstalled package pymosp 0.5.0, Python 3.10.2\nThese apps are now globally available\n  - pymosp\ndone! ✨ 🌟 ✨\n\n$ export MOSP_URL_API=https://objects.monarc.lu/api/v2/\n$ export TOKEN=<YOUR-TOKEN>\n\n$ pymosp object --list\n{\'metadata\': {\'count\': \'5074\', \'offset\': \'0\', \'limit\': \'10\'}, \'data\': [{\'id\': 144, \'name\': \'Use of an obsolete version of the messaging server\', \'description\': \'\', \'schema_id\': 14, \'org_id\': 4, \'last_updated\': \'2021-03-16T12:45:35.046659\', \'json_object\': {\'code\': \'1118\', \'uuid\': \'69fc03a0-4591-11e9-9173-0800277f0571\', \'label\': \'Use of an obsolete version of the messaging server\', \'language\': \'EN\', \'description\': \'\'}, \'organization\': {\'id\': 4, \'name\': \'MONARC\', \'description\': \'MONARC is a tool and a method allowing an optimised, precise and repeatable risk assessment.\', \'organization_type\': \'Non-Profit\', \'is_membership_restricted\': True, \'last_updated\': \'2018-05-18T09:50:57\'}, \'licences\': None},  ... ,  {\'id\': 284, \'name\': \'Tempting equipment (trading value, technology, strategic)\', \'description\': \'\', \'schema_id\': 14, \'org_id\': 4, \'last_updated\': \'2021-03-16T12:45:33.862787\', \'json_object\': {\'code\': \'278\', \'uuid\': \'69fc0ee2-4591-11e9-9173-0800277f0571\', \'label\': \'Tempting equipment (trading value, technology, strategic)\', \'language\': \'EN\', \'description\': \'\'}, \'organization\': {\'id\': 4, \'name\': \'MONARC\', \'description\': \'MONARC is a tool and a method allowing an optimised, precise and repeatable risk assessment.\', \'organization_type\': \'Non-Profit\', \'is_membership_restricted\': True, \'last_updated\': \'2018-05-18T09:50:57\'}, \'licences\': None}]}\n```\n\n### Use it as a Python library\n\n```bash\npip install pymosp\n```\n\n```python\nimport pymosp, os\nmosp = pymosp.PyMOSP(os.getenv("MOSP_URL_API"), os.getenv("TOKEN"))\nparams = {"organization": "MONARC", "schema": "Library objects"}\nr = mosp.objects(params=params)\nprint(r)\n```\n\n\nor via the Git repository:\n\n```bash\n$ git clone https://github.com/CASES-LU/PyMOSP\n$ cd PyMOSP\n$ poetry install\n$ poetry run nose2 -v --pretty-assert\n```\n\n\n## Examples\n\nSee the examples in the file [example.py](example.py) or in the tests folder.\n\n\n## License\n\nThis software is licensed under\n[GNU General Public License version 3](https://www.gnu.org/licenses/gpl-3.0.html).\n\n* Copyright (C) 2019-2022 Cédric Bonhomme\n* Copyright (C) 2019-2022 SECURITYMADEIN.LU\n\nFor more information, [the list of authors and contributors](AUTHORS.md)\nis available.\n',
    'author': 'Cédric Bonhomme',
    'author_email': 'cedric@cedricbonhomme.org',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/CASES-LU/PyMOSP',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
